# CNAs with HTML advisories

## Adobe Systems Incorporated
### Advisory
https://helpx.adobe.com/security/alertus.html 
#### Notes
Advisories are located here: https://helpx.adobe.com/security/security-bulletin.html. This page can be used as an index to get all individual adivsory ids.
Each advisory has HTML tables with tr and td tags. h1 and h2 tags for validation of specific headings.
[adobe_security_bulletin_example](img/adobe_security_bulletin_example.png)
#### Captured Data Potential From Advisory
```
{
  :bulletin_id => 'APSB22-21',
  :date_published => 'May 10, 2022',
  :priority => '3',
  :summary => 'Adobe has released an update for Adobe Character Animator for Windows and macOS. This update resolves a critical vulnerability. Successful exploitation could lead to arbitrary code execution' ,
  :affected_versions => [{:product => 'Character Animator 2021', :version => '4.4.2 and earlier versions', :platform => 'Windows and macOS'}, {:product => 'Character Animator 2022', :version => '22.3 and earlier versions', :platform => 'Windows and macOS'}],
  :solution => [{:product => 'Character Animator 2021', :version => '4.4.7', :platform => 'Windows and macOS', :priority_rating => '3', :availability => 'https://www.adobe.com/creativecloud/catalog/desktop.html' }, {:product => 'Character Animator 2022', :version => '22.4', :platform => 'Windows and macOS', :availability => 'https://www.adobe.com/creativecloud/catalog/desktop.html'}],
  :vulnerability_details => [{:vulnerability_category => 'Out-of-bounds Write (CWE-787)', :vulnerability_impact => 'Arbitrary code execution', :severity => 'Critical', :cvss_base_score => '7.8', :cvss_vector => 'CVSS:3.0/AV:L/AC:L/PR:N/UI:R/S:U/C:H/I:H/A:H', :cve_numbers => 'CVE-2022-28819'}]
}
```

## AMD
### Advisory
https://www.amd.com/en/corporate/product-security
#### Captured Data Potential From Advisory
```
# Note: Additional advisories have some more keys than the example shown below
# for example: AMD-SB-1028 also has a :cve_details table with :cve, :cvss_score, :cve_description in each row. 
{
  :bulletin_id => 'AMD-SB-1033',
  :potential_impact => 'Data leakage',
  :severity =>'Medium',
  :summary => 'AMD received notification of a potential security vulnerability where data in specific cryptographic algorithms can be inferred in a SEV guest by monitoring the ciphertext values over time.  Researchers from the Institute for IT-Security University of Luebeck and The Ohio State University will present their paper titled “A Systematic Look at Ciphertext Side Channels on AMD SEV-SNP” at the 43rd IEEE Symposium on Security and Privacy scheduled for May 23-25, 2022. CVE-2021-46744 An attacker with access to a malicious hypervisor may be able to infer data values used in a SEV guest on AMD CPUs by monitoring ciphertext values over time.',
  :affected_products => ['1st/2nd/3rdGen AMD EPYC™ Processors', 'AMD EPYC™ Embedded Processors'],
  :mitigation => 'AMD has provided guidance via an updated paper located here: TECHNICAL GUIDANCE FOR MITIGATING EFFECTS OF CIPHERTEXT VISIBILITY UNDER AMD SEV As of the date of this notice, AMD is not aware of any active exploits in the wild of CVE-2021-46744 on AMD products. We continue to look for ways to make our products more secure, including working closely with partners, academics, researchers, and end-users in the ecosystem.',
  :references => 'https://www.amd.com/system/files/documents/221404394-a_security_wp_final.pdf'
}
```

## Ampere
#### Advisory
https://amperecomputing.com/products/product-security.html
#### Captured Data Potential From Advisory
```
{
  :bulletin_id => 'AMP-SB-0001',
  :potential_impact => 'Partial loss of protected data',
  :severity => 'Medium: CVSS score is 4.7',
  :summary => '[CVSS:3.1/AV:L/AC:H/PR:L/UI:N/S:U/C:N/I:H/A:N] 3/8/2022: Ampere investigated the potential impacts of the Spectre-BHB to Ampere products. The description of the vulnerability, published by the national vulnerability database (NVD) states: CVE-2022-25368 Spectre BHB is a variant of Spectre-v2 in which malicious code uses the shared branch history (stored in the CPU BHB) to influence mispredicted branches in the victim's hardware context. Speculation caused by these mispredicted branches can then potentially be used to cause cache allocation, which can then be used to infer information that should be protected.',
  :affected_products => 'Ampere® Altra® and Ampere® Altra® Max',
  :recommendations => 'Ampere recommends that users of affected products update to the latest firmware version provided by the system manufacturer that addresses these issues. Ampere also recommends updating to the latest OS updates that that addresses these issues. Disable unprivileged Extended Berkeley Packet Filter (eBPF)',
  :references => [
    'https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-25368',
    'https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2022-23960',
    'https://developer.arm.com/support/arm-security-updates/speculative-processor-vulnerability/spectre-bhb'
  ]
}
```

## Android
### Advisory
https://source.android.com/security/bulletin
#### Notes
We need to figure out a way to parse these google bulletins. Headings and tables. the CVE data is in the tables.
#### Captured Data Potential From Advisory

## Apple Inc.
### Advisory
https://support.apple.com/en-us/HT201222
#### Captured Data Potential From Advisory
```
[
  {
    "cves": [
      {
        "cve_id": "CVE-2017-2372",
        "cve_author": "Tyler Bohan of Cisco Talos"
      }
    ],
    "name":
      {
        "name": "Projects"
      },
    "available_for": "OS X El Capitan v10.11 and later (64 bit)",
    "description": "A memory corruption issue was addressed through improved memory handling.",
    "impact": "Opening a maliciously crafted GarageBand project file may lead to arbitrary\u00a0code execution"
  }
]
```

## Arista Networks
### Advisory
https://www.arista.com/en/support/advisories-notices 
#### Notes
Offers a subscribe with RSS button to get an index of advisories at least.
#### Captured Data Potential From Advisory
```
{
  :bulletin_id => 'Security Advisory 0068',
  :date => 'August 20th, 2021',
  :version => '1.0',
  :revision => [{:version => '1.0', :date => 'August 20th, 2021', :changes => 'Initial Release'}],
  :cve_id => 'CVE-2021-28494',
  :cvss_base_score => '9.6( CVSS:3.1/AV:N/AC:L/PR:L/UI:N/S:C/C:N/I:H/A:H)',
  :description => 'This advisory documents the impact of an internally found vulnerability in Arista's MOS (Metamako Operating System) software which is supported on the 7130 product line. The effect of this vulnerability is that, under certain conditions, authentication is bypassed by unprivileged users who are accessing the Web UI. This issue was discovered internally and Arista is not aware of any malicious uses of this issue in customer networks.',
  :vulnerability_assessment => {
    :affected_software => 'MOS-0.34.0 and prior releases',
    :affected_platforms => { 
      :affected_products => ['Arista 7130 Systems running MOS'], 
      :non_affected_products => [
        'Arista EOS-based products',
        'Arista Converged Cloud Fabric and DANZ Monitoring Fabric (Formerly Big Switch Nodes for BCF and BMF)',
        'Arista Wireless Access Points',
        'CloudVision Wi-Fi (on-premise and cloud service delivery)',
        'CloudVision Portal, virtual appliance or physical appliance',
        'CloudVision as-a-Service',
        'Awake Security Platform'
      ]}},
  :symptoms => 'Check if the installed software version falls under the list specified in the “Affected Software” section:',
  :mitigation => 'Web UI access to the affected systems is enabled by default and can be disabled by using the following commands. However, note that this will break any automation that relies on Web UI or JSON API access to the system and should be used only if Web UI and JSON API access is not required for managing the system.',
  :resolution => 'This vulnerability is being tracked by BUG567401. The recommended resolution is to upgrade to a remediated MOS version during a maintenance window. This vulnerability has been fixed in the following MOS version: MOS-0.35.0',
}
```

## Atlassian
### Advisory
https://www.atlassian.com/trust/security/advisories 
#### Notes
The page listed in the CNAList.json for this org is the advisory policy document and not the list of advisories. The link provided in this document is the correct link for security advisories
#### Captured Data Potential From Advisory
```
{
  :bulletin_id => 'Jira Security Advisory 2022-04-20',
  :summary_table => {
    :summary => 'CVE-2022-0540 - Authentication bypass in Seraph',
    :advisory_release_date => '20 Apr 2022 10:00 AM PDT (Pacific Time, -7 hours)',
    :affected_products => [
      'Jira', 
      'Jira Core Server',
      'Jira Software Server',
      'Jira Software Data Center',
      'Jira Service Management',
      'Jira Service Management Server',
      'Jira Service Management Data Center'
    ],
    :cve_ids => 'CVE-2022-0540'
  },
  :summary_of_vulnerability => 'Jira and Jira Service Management are vulnerable to an authentication bypass in its web authentication framework, Jira Seraph. Although the vulnerability is in the core of Jira, it affects first and third party apps that specify roles-required at the webwork1 action namespace level and do not specify it at an action level. For a specific action to be affected, the action will also need to not perform any other authentication or authorization checks. A remote, unauthenticated attacker could exploit this by sending a specially crafted HTTP request to bypass authentication and authorization requirements in WebWork actions using an affected configuration.',
  :severity => 'For installations that use apps that have an affected configuration, Atlassian rates the severity level of this vulnerability as critical, though this may vary if an affected app uses additional permissions checks. For more detailed information on the impact to each app listed in the Determining which apps are affected section below, contact the app vendor. For installations that do not use any apps that have an affected configuration as described in the Summary of Vulnerability section above, Atlassian rates the severity level of this vulnerability as medium. This is our assessment, and you should evaluate its applicability to your own IT environment.',
  :affected_jira_versions => [
    'Jira Core Server',
    'Jira Software Server',
    'Jira Software Data Center',
    'All versions before 8.13.18',
    '8.14.x',
    '8.15.x',
    '8.16.x',
    '8.17.x',
    '8.18.x',
    '8.19.x',
    '8.20.x before 8.20.6',
    '8.21.x'
  ],
  :fixed_jira_versions => [
    '8.13.x >= 8.13.18',
    '8.20.x >= 8.20.6',
    'All versions >= 8.22.0'
  ],
  :fixed_jira_service_management_versions => [
    '4.13.x >= 4.13.18',
    '4.20.x >= 4.20.6',
    'All versions >= 4.22.0'
  ]
}
```

## Autodesk
### Advisory
https://www.autodesk.com/trust/security-advisories
#### Captured Data Potential From Advisory
```
{
  :bulletin_id => 'ADSK-SA-2022-0010',
  :product_service_component => 'Autodesk® 3ds Max®',
  :impact => 'Out-of-bound Read/Write',
  :severity => 'High',
  :original_publish => '5/4/2022',
  :last_revised => '5/4/2022',
  :summary => 'Applications and services that utilize Autodesk 3ds Max may be affected by Out-of-bound Read/Write vulnerabilities. Exploitation of these vulnerabilities may lead to remote code execution.',
  :description => 'The details of the vulnerabilities are as follows: 1) CVE-2022-27531 - A maliciously crafted TIF file can be forced to read beyond allocated boundaries in Autodesk 3ds Max 2022, and 2021 when parsing the TIF files. This vulnerability in conjunction with other vulnerabilities could lead to code execution in the context of the current process. 2) CVE-2022-27532 - A maliciously crafted TIF file in Autodesk 3ds Max 2022 and 2021 can be used to write beyond the allocated buffer while parsing TIF files. This vulnerability in conjunction with other vulnerabilities could lead to arbitrary code execution.',
  :affected_products =>[
    { 
      :item => 'Autodesk® 3ds Max®',
      :impacted_versions => '2022,2021',
      :mitigated_versions => '2022.3.3, 2021.3.8',
      :updated_source => 'Autodesk Desktop App, or Accounts Portal'
    }
  ],
  :revision_history => [
    {
      :revision => '1.0',
      :date => '5/4/2022',
      :description => 'Description: Initial Release of Security advisory'
    }
  ]
}
```

## Avaya, Inc
### Advisory
https://support.avaya.com/security
#### Captured Data Potential From Advisory
```
{
  :bulletin_id => 'ASA-2017-350',
  :overview => 'PostgreSQL is an advanced object-relational database management system (DBMS). Privilege escalation flaws were found in the initialization scripts of PostgreSQL. An attacker with access to the postgres user account could use these flaws to obtain root access on the server machine. The Common Vulnerabilities and Exposures project (cve.mitre.org) has assigned the names CVE-2017-12172 and CVE-2017-15097 to these issues. More information about these vulnerabilities can be found in the security advisory issued by Red Hat: https://access.redhat.com/errata/RHSA-2017:3402',
  :affected_packages => [
    {
      :product => 'Avaya Aura® Application Enablement Services',
      :versions => '7.1.0.0 through 7.1.2.0',
      :resolution => 'Upgrade to 7.1.3.0 or later',
      :information => 'The risk is mitigated because only administrative users have access to the database by default.'
    },
    {
      :product => 'Avaya Aura® Utility Services',
      :versions => '7.1.0.0 through 7.1.2.0',
      :resolution => 'Upgrade to 7.1.3.0 or later',
      :information => 'The risk is mitigated because only administrative users have access to the database by default.'
    }
  ],
  :cvss_3.0_scoring_and_metrics => [
    {
      :vulnerability => 'CVE-2017-12172',
      :cvssv3_base_score => '6.5 (Medium)',
      :cvssv3_metrics => 'CVSS:3.0/AV:L/AC:L/PR:H/UI:R/S:U/C:H/I:H/A:H',
    },
    {
      :vulnerability => 'CVE-2017-15097',
      :cvssv3_base_score => '6.5 (Medium)',
      :cvssv3_metrics => 'CVSS:3.0/AV:L/AC:L/PR:H/UI:R/S:U/C:H/I:H/A:H'
    }
  ],
  :avaya_software_only_products => [
    {
      :product => 'Avaya Aura® Application Enablement Services',
      :actions => 'Depending on the Operating System installed, the affected package may be installed on the underlying Operating System supporting the AES application.'
    },
    {
      :product => 'Oceanalytics Elite',
      :actions => 'Depending on the Operating System installed, the affected package may be installed on the underlying Operating System supporting the application.'
    }
  ],
  :revision_history => [
    {
      :version => '1.0',
      :date => 'December 18, 2017',
      :description => 'Initial Statement issued.',
    },
    {
      :version => '2.0',
      :date => 'August 29, 2018',
      :description => 'Updated versions and resolution for all products and set advisory status to Final.'
    }
  ]
}
```

## Becton, Dickinson and Company (BD)
### Advisory
https://cybersecurity.bd.com/bulletins-and-patches
#### Notes
There is a filter on the left-hand size of the list. filtering bulletins allows you to get the security bulletins.
Each bulletin may have some different keys than what is in the provided example below:
#### Captured Data Potential From Advisory
```
# Some additional keys on other advisories: 
{
  :bulletin_id => 'Apache Log4j Vulnerability: BD Third-Party Components Impacted',
  :background => 'BD is aware of and currently monitoring Apache Log4J vulnerabilities which impact third-party product(s) that are utilized with certain BD software-enabled products. These third-party vulnerabilities are not specific to BD or our products. A malicious actor with network access to an impacted product may exploit this issue to gain full control of the target system and/or perform denial-of-service attacks. BD has not received any reports regarding these vulnerabilities being exploited on BD products.',
  :scope => [
    {
      :cve_id => 'CVE-2021-44228',
      :severity => 'Critical',
      :description => 'Apache Log4j2 2.0-beta9 through 2.12.1 and 2.13.0 through 2.15.0 JNDI features used in configuration, log messages, and parameters do not protect against attacker-controlled LDAP and other JNDI related endpoints. An attacker who can control log messages or log message parameters can execute arbitrary code loaded from LDAP servers when message lookup substitution is enabled.'
    },
    {
      :cve_id => 'CVE-2021-45046',
      :severity => 'Critical',
      :description => 'It was found that the fix to address CVE-2021-44228 in Apache Log4j 2.15.0 was incomplete in certain non-default configurations. This could allow attackers with control over Thread Context Map (MDC) input data when the logging configuration uses a non-default Pattern Layout with either a Context Lookup (for example, $${ctx:loginId}) or a Thread Context Map pattern (%X, %mdc, or %MDC) to craft malicious input data using a JNDI Lookup pattern resulting in an information leak and remote code execution in some environments and local code execution in all environments.'
    }
  ],
  :response => 'BD is currently working to test and validate the patch(es) or other mitigations for BD products that use the affected third-party components. Some patches may already be available. Please refer to the Bulletins and Patches page for all approved product security patching notifications. Additionally, we recommend the following compensating controls for customers using BD products that utilize impacted third-party components.Execute updates to malware protection, where available. Ensure data has been backed up and stored according to your individual processes and disaster recovery procedures. Do not allow unauthorized access to the network. Only allow authorized users to have access to the network/system. Ensure your firewall and antivirus protection are updated with the latest updates. Minimize network exposure to devices and ensure devices are not directly accessible from the internet unless essential.Customers that maintain patches independent of BD automated delivery should ensure that available security patches and recommendations are applied as the acting responsible entity in order to maintain the correct security posture of the system(s).',
  :affected_third_party_products => [
    { 
      :third_party_component => 'VMware vCenter',
      :products => [
        'BD Kiestra™ Total Lab Automation (TLA) with a Systems Control Unit (SCU)',
        'BD Kiestra™ Work Cell Automation (WCA) with a Systems Control Unit (SCU)',
        'BD Kiestra™ ReadA with a Systems Controls Unit (SCU)'
      ]
    }
  ],
  :additional_resources => 'VMWare Advisory: https://www.vmware.com/security/advisories/VMSA-2021-0028.html'
}

```
## Bitdefender
### Advisory
https://www.bitdefender.com/support/security-advisories/
#### Notes
404 on the advisory page for me
#### Captured Data Potential From Advisory

## BlackBerry
### Advisory
https://www.blackberry.com/us/en/services/blackberry-product-security-incident-response
#### Captured Data Potential From Advisory
```
{
  :bulletin_id => 'QNX-2022-001',
  :article_number => '000090868',
  :first_published => '',
  :last_modified => 'January 11, 2022',
  :type => 'security_advisory',
  :overview => 'This advisory addresses an elevation of privilege vulnerability in the QNX Neutrino Kernel of affected versions of QNX Software Development Platform (SDP), QNX OS for Medical (QOSM), and QNX OS for Safety (QOS) that could potentially allow a successful attacker to access data, modify behavior, or permanently crash the system. BlackBerry is not aware of any exploitation of this vulnerability. BlackBerry investigates all reports of security vulnerabilities affecting supported products and services. A security advisory is issued once the investigation is complete and the software update is released. Installing the recommended update(s) in this advisory will help maintain the security of your BlackBerry products(s). ',
  :vulnerability_information =>
  {
    :cve_identifier => 'CVE-2021-32025',
    :vulnerability_type => 'Elevation of privilege',
    :cvss_score => '8.1',
    :affected_products => [
      'QNX SDP versions 6.4.0 to 7.0',
      'QNX® Momentics® all 6.3.x versions',
      'QNX OS for Safety versions 1.0.0 to 1.0.2 safety products compliant with IEC 61508 and/or ISO 26262 ',
      'QNX OS for Safety versions 2.0.0 to 2.0.1 safety products compliant with IEC 61508 and/or ISO 26262 ',
      'QNX OS for Medical versions 1.0.0 to 1.1.1 safety products compliant with IEC 62304',
      'QNX OS for Medical versions 2.0.0 safety product compliant with IEC 62304'
    ],
    :affected_components => [
      'QNX Neutrino Kernel - The kernel implements the core POSIX features used in embedded real-time systems, along with the fundamental QNX Neutrino message-passing services.'
    ],
    :non_affected_products => [
      'QNX SDP 7.0 (com.qnx.sdp.target.microkernel.core version 7.0.4298.S202111170916)',
      'QNX SDP 6.6.0 with Patch ID 4884 applied',
      'QNX SDP 6.5.0SP1 with Patch ID 4880 applied',
      'QNX SDP 6.4.1 with Patch ID 4891 applied',
      'QNX Momentics Development Suite 6.3.2 with Patch ID 4892 applied',
      'QNX OS for Safety versions 1.0.3 safety products compliant with IEC 61508 and/or ISO 26262',
      'QNX OS for Safety version 2.0.2 safety products compliant with IEC 61508 and/or ISO 26262 (com.qnx.sdp.target.qos.group version 2.0.643.S202110182332)',
      'QNX OS for Medical versions 1.1.2 safety products compliant with IEC 62304 with patch ID 4888',
      'QNX OS for Medical version 2.0.1 safety products compliant with IEC 62304 (com.qnx.sdp.target.qosm.group version 2.0.23.S202110290907)',
      'System hardware architectures other than 32-bit x86',
      'QNX SDP 7.1 and later versions',
      'QNX OS for Safety 2.1 and later versions'
    ],
    :who_should_read_this_advisory_apply_software_updates => 'Developers, administrators, and project managers who develop, maintain, or support affected QNX-based systems.',
    :requirements_for_attacker_to_be_succesful => 'To exploit this vulnerability, an attacker must either persuade a user to execute malicious code or exploit an unrelated weakness to gain unrestricted ability to execute code',
    :impact_if_requirements_met => 'If the requirements are met for exploitation, a successful attacker could potentially access data, modify behavior, or permanently crash the system.',
    :mitigation => 'This issue is mitigated by the requirement that an attacker must first gain local access to the system, either via manipulating a valid user or by an unrelated weakness in the system. This issue is mitigated completely in systems running on hardware architectures other than 32-bit x86. This issue is also mitigated in systems that do not allow arbitrary programs to be run.',
    :workarounds_recommendations => 'There are no workarounds for this vulnerability.',
    :software_updates => [
      'QNX SDP 6.6.0 https://www.qnx.com/download/group.html?programid=26071',
      'QNX SDP 6.5.0SP1 https://www.qnx.com/download/group.html?programid=20905',
      'QNX SDP 6.4.1 https://www.qnx.com/download/group.html?programid=18770',
      'QNX Momentics Development Suite 6.3.2 https://www.qnx.com/download/group.html?programid=17103',
      'QNX OS for Safety 1.0.3 http://www.qnx.com/download/group.html?programid=27165',
      'QNX OS for Medical 1.1.2 http://www.qnx.com/download/group.html?programid=26463'
    ]
  }
}
```

## Brocade Communication Systems, LLC
### Advisory
https://www.broadcom.com/support/fibre-channel-networking/security-advisories
#### Captured Data Potential From Advisory
```
{
  :bulletin_id => 'BSA-2022-1844',
  :initial_publication_date => '05/04/22',
  :last_updated => '05/04/22',
  :revision => '1.0',
  :risk_impact => 'High',
  :workaround => 'N/A',
  :component => 'RBAC',
  :affected_cve => 'CVE-2022-28165',
  :cvss_score => '8.0 - CVSS:3.1/AV:N/AC:H/PR:H/UI:N/S:C/C:H/I:H/A:H',
  :description => 'A vulnerability in the role-based access control (RBAC) functionality of the Brocade SANNav before 2.2.0 could allow an authenticated, remote attacker to access resources that they should not be able to access and perform actions that they should not be able to perform. The vulnerability exists because restrictions are not performed on Server side to ensure the user has required permission before processing requests.',
  :affected_products => [
    'Brocade SANnav - Fixed in Brocade SANnav 2.2.0'
  ],
  :product_confirmed_not_vulnerable => 'No other Brocade Fibre Channel Products from Broadcom products are currently known to be affected by this vulnerability.',
  :credit => 'The issue was discovered in penetration testing.',
  :revision_history => [
    {
      :version => '1.0',
      :change => 'Initial Publication',
      :date => 'May 3, 2022'
    }
  ]
}
```

## CA Technologies - A Broadcom Company
### Advisory
- Software advisories: https://support.broadcom.com/security-advisory/security-advisories-list.html?segment=ES
- Mainframe advisories: https://support.broadcom.com/security-advisory/security-advisories-list.html?segment=MF
#### Notes
Both pages need an account to login to view advisories
#### Captured Data Potential From Advisory

## CERT/CC
### Advisory
https://www.kb.cert.org/vuls/bypublished/desc/
#### Notes
https://vuls.cert.org/confluence/display/VIN/Vulnerability+Note+Help This page gives definitions of terms used in their advisories which they call vulnerability notes.
#### Captured Data Potential From Advisory

## CERT@VDE
### Advisory
https://cert.vde.com/en/advisories/
#### Captured Data Potential From Advisory
```
{
  :bulletin_id => 'VDE-2022-021',
  :published => '2022-05-16 14:00 (CEST)',
  :last_update => '2022-05-16 16:16 (CEST)',
  :vendors => [' Pepperl+Fuchs SE'],
  :products => [
    {
      :article_no => '',
      :product_name => 'RSM-EX01B Product Family',
      :affected_versions => [
        'all versions'
      ]
    }
  ],
  :summary => 'Critical vulnerabilities have been discovered in the utilized Bluetooth component. For more information see: https://kb.cert.org/vuls/id/799380 external link',
  :vulnerabilities => [
    {
      :cve_id => 'CVE-2020-26559',
      :severity => '8.8 (CVSS:3.1/AV:A/AC:L/PR:N/UI:N/S:U/C:H/I:H/A:H)',
      :weakness => 'Incorrect Authorization (CWE-863)',
      :summary => 'Bluetooth Mesh Provisioning in the Bluetooth Mesh profile 1.0 and 1.0.1 may permit a nearby device (participating in the provisioning protocol) to identify the AuthValue used given the Provisioner’s public ...',
      :source => 'https://nvd.nist.gov/vuln/detail/CVE-2020-26559'
    },
    {
      :cve_id => 'CVE-2020-26560',
      :severity => '8.1 (CVSS:3.1/AV:A/AC:L/PR:N/UI:N/S:U/C:H/I:H/A:N)',
      :weakness => 'Incorrect Authorization (CWE-863)',
      :summary => 'Bluetooth Mesh Provisioning in the Bluetooth Mesh profile 1.0 and 1.0.1 may permit a nearby device, reflecting the authentication evidence from a Provisioner, to complete authentication without possessing the AuthValue, ...',
      :source => 'https://nvd.nist.gov/vuln/detail/CVE-2020-26560'
   },
   {
     :cve_id => 'CVE-2020-26556',
     :severity => '7.5 (CVSS:3.1/AV:A/AC:H/PR:N/UI:N/S:U/C:H/I:H/A:H)',
     :weakness => 'Improper Restriction of Excessive Authentication Attempts (CWE-307)',
     :summary => 'Mesh Provisioning in the Bluetooth Mesh profile 1.0 and 1.0.1 may permit a nearby device, able to conduct a successful brute-force attack on an insufficiently random AuthValue before the provisioning ...',
     :source => 'https://nvd.nist.gov/vuln/detail/CVE-2020-26556'
   },
   {
     :cve_id => 'CVE-2020-26557',
     :severity => '7.5 (CVSS:3.1/AV:A/AC:H/PR:N/UI:N/S:U/C:H/I:H/A:H)',
     :weakness => 'Incorrect Authorization (CWE-863)',
     :summary => 'Mesh Provisioning in the Bluetooth Mesh profile 1.0 and 1.0.1 may permit a nearby device (without possession of the AuthValue used in the provisioning protocol) to determine the AuthValue via ...',
     :source => 'https://nvd.nist.gov/vuln/detail/CVE-2020-26557'
   },
   {
     :cve_id => 'CVE-2020-26555',
     :severity => '5.4 (CVSS:3.1/AV:A/AC:L/PR:N/UI:N/S:U/C:L/I:L/A:N)',
     :weakness => 'Incorrect Authorization (CWE-863)',
     :summary => 'Bluetooth legacy BR/EDR PIN code pairing in Bluetooth Core Specification 1.0B through 5.2 may permit an unauthenticated nearby device to spoof the BD_ADDR of the peer device to complete pairing ...',
     :source => 'https://nvd.nist.gov/vuln/detail/CVE-2020-26555'
   },
   {
     :cve_id => 'CVE-2020-26558',
     :severity => '4.2 (CVSS:3.1/AV:A/AC:H/PR:N/UI:N/S:U/C:L/I:L/A:N)',
     :weakness => 'Improper Authentication (CWE-287)',
     :summary => 'Bluetooth LE and BR/EDR secure pairing in Bluetooth Core Specification 2.1 through 5.2 may permit a nearby man-in-the-middle attacker to identify the Passkey used during pairing (in the Passkey authentication ...',
     :source => 'https://nvd.nist.gov/vuln/detail/CVE-2020-26558'
   }
  ],
  :impact => 'Pepperl+Fuchs analyzed and identified affected devices. An unauthorized attacker could gain access to the audio communication and listen to the conversation via Bluetooth. This attack can only be carried out at close range and is limited by the radio range of Bluetooth. The impact of the vulnerabilities on the affected device may result in information disclosure',
  :solution => 'The device will play a confirmation sound when a Bluetooth connection is successfully established and a status LED labeled BT indicates that a Bluetooth connection is active. This can be used to detect an unauthenticated connection.',
  :reported_by => 'Pepperl+Fuchs Coordinated by CERT@VDE'
}
```

## Checkpoint
### Advisory
https://www.checkpoint.com/advisories/
#### Captured Data Potential From Advisory
```
{
  :bulletin_id => 'CPAI-2022-0251',
  :date_published => 'May 19, 2022',
  :severity => 'Critical',
  :last_updated => 'Thursday 19 May, 2022',
  :source => '',
  :cve_id => 'CVE-2022-30525',
  :protection_provided_by => 'Security Gateway R81, R80, R77, R75',
  :who_is_vulnerable => [
    'Zyxel USG FLEX 100(W) firmware versions 5.00 through 5.21 Patch 1',
    'Zyxel USG FLEX 200 firmware versions 5.00 through 5.21 Patch 1',
    'Zyxel USG FLEX 500 firmware versions 5.00 through 5.21 Patch 1',
    'Zyxel USG FLEX 700 firmware versions 5.00 through 5.21 Patch 1',
    'Zyxel USG FLEX 50(W) firmware versions 5.10 through 5.21 Patch 1',
    'Zyxel USG20(W)-VPN firmware versions 5.10 through 5.21 Patch 1',
    'Zyxel ATP series firmware versions 5.10 through 5.21 Patch 1',
    'Zyxel VPN series firmware versions 4.60 through 5.21 Patch 1'
  ],
  :vulnerability_description => 'A command injection vulnerability exists in Zyxel USG. Successful exploitation of this vulnerability could allow a remote attacker to execute arbitrary commands on the affected system.'
}
```

## Chrome
### Advisory
https://www.google.com/about/appsecurity/research/
#### Notes
CNA json lists https://www.google.com/about/appsecurity/research/ which redirects to their bughutner portal. Navigating from there to this page shows some public reports: https://bughunters.google.com/report/reports
#### Captured Data Potential From Advisory

## CISA - ICS
### Advisory
https://www.cisa.gov/uscert/ics/alerts 
#### Notes
They offer an rss feed to get the index of advisories
#### Captured Data Potential From Advisory

## Cyber Security Works Pvt. Ltd.
### Advisory
https://cybersecurityworks.com/zerodays-vulnerability-list/
#### Notes
Paginated list of vulns. 
#### Captured Data Potential From Advisory

## Dahua Technologies
### Advisory
https://www.dahuasecurity.com/support/cybersecurity/annoucementNotice
#### Notes
Paginated index of vulns.
#### Captured Data Potential From Advisory

## Debian Gnu/Linux
### Advisory
https://www.debian.org/security/#DSAS
#### Notes
Wide range of formats.
#### Captured Data Potential From Advisory

## DeepSurface Security, Inc
### Advisory
https://deepsurface.com/tag/blog/
#### Notes
The page has advisories but also just regular release notes and blog posts
#### Captured Data Potential From Advisory

## Dell
### Advisory
https://www.dell.com/support/security/en-us
### Notes
Has an Export table button that can be used to export the index of cves to a spreadsheet
#### Captured Data Potential From Advisory

## Devolutions Inc.
### Advisory
https://devolutions.net/security/advisories/
#### Notes
HTML table for index. subscribe to security advisories via email on bottom of index page.
#### Captured Data Potential From Advisory

## Document Foundatino, The
### Advisory
https://www.libreoffice.org/about-us/security/advisories/
#### Notes
Header and p tags for index
#### Captured Data Potential From Advisory

## Drupal.org
### Advisory
https://www.drupal.org/security
#### Notes
Heading and p tags for index
#### Captured Data Potential From Advisory

## Elastic
### Advisory
https://www.elastic.co/community/security
#### Notes
HTML table index has everything. cve-id links to mitre. ESA-ID, CVE, Date Disclosed, Vulnerability Summary, Remediation Summary
#### Captured Data Potential From Advisory
```
{ 
  :esa_id => "ESA-2021-09",
  :cve => "CVE-2021-22138", 
  :date_disclosed => "2021-03-23",
  :vulnerability_summary => "A TLS certificate validation flaw was found in the monitoring feature of Logstash versions 6.4.0 and before versions 6.8.15 and 7.12.0. When specifying a trusted server CA certificate Logstash would not properly verify the certificate returned by the monitoring server. This could result in a man in the middle style attack against the Logstash monitoring data.",
  :remediation_summary => "Users should update their version of Logstash to 7.12.0 or 6.8.15."
}
```